@@ -6,6 +6,8 @@ import concurrent
 import logging
 from typing import Any, Dict, List
 
+import requests
+
 from griffon import CORGI_API_URL, OSIDB_API_URL, CorgiService, OSIDBService
 
 logger = logging.getLogger("griffon")
@@ -125,7 +127,9 @@ class products_containing_specific_component_query:
         "component_type",
         "strict_name_search",
         "affect_mode",
-        "search_deps",
+        "search_all",
+        "search_related_url",
+        "search_community",
     ]
 
     def __init__(self, params: dict) -> None:
@@ -153,7 +157,9 @@ class products_containing_component_query:
         "component_type",
         "strict_name_search",
         "affect_mode",
-        "search_deps",
+        "search_all",
+        "search_related_url",
+        "search_community",
     ]
 
     def __init__(self, params: dict) -> None:
@@ -164,6 +170,9 @@ class products_containing_component_query:
         self.strict_name_search = self.params.get("strict_name_search")
         self.search_deps = self.params.get("search_deps")
         self.ns = self.params.get("namespace")
+        self.search_all = self.params.get("search_all")
+        self.search_related_url = self.params.get("search_related_url")
+        self.search_community = self.params.get("search_community")
 
     def execute(self) -> List[Dict[str, Any]]:
         cond = {"view": "latest"}
@@ -176,7 +185,55 @@ class products_containing_component_query:
             cond["type"] = self.component_type
 
         result = self.corgi_session.components.retrieve_list(**cond, limit=1000)
-        return result.results
+
+        results = result.results
+        if self.search_related_url:
+            # TODO - not in bindings yet
+            related_url_search = requests.get(
+                f"{CORGI_API_URL}/api/v1/components",
+                params={
+                    "include_fields": "name,arch,namespace,release,version,nvr,type,link,purl,software_build,product_versions,product_streams,sources",  # noqa
+                    "related_url": self.component_name,
+                    "limit": 10000,
+                },
+            )
+
+            for c in related_url_search.json()["results"]:
+                for pv in c["product_versions"]:
+                    for ps in c["product_streams"]:
+
+                        is_dep = False
+                        if c["arch"] == "src" or c["arch"] == "noarch":
+                            is_dep = True
+                        component = {
+                            "is_dep": is_dep,
+                            "product_version": pv["name"],
+                            "product_version_ofuri": pv["ofuri"],
+                            "product_stream": ps["name"],
+                            "product_stream_ofuri": ps["ofuri"],
+                            "product_active": True,
+                            "purl": c["purl"],
+                            "type": c["type"],
+                            "namespace": c["namespace"],
+                            "name": c["name"],
+                            "arch": c["arch"],
+                            "release": c["release"],
+                            "version": c["version"],
+                            "sources": c["sources"],
+                            "nvr": c["nvr"],
+                            "build_id": None,
+                            "build_type": None,
+                            "build_source_url": None,
+                            "related_url": None,
+                            "upstream_purl": None,
+                        }
+                        if c["software_build"]:
+                            component["build_id"] = c["software_build"]["build_id"]
+                            component["build_type"] = c["software_build"]["build_type"]
+                            component["build_source_url"] = c["software_build"]["source"]
+                        results.append(component)
+
+        return results
 
 
 class components_containing_specific_component_query:
@@ -444,7 +501,7 @@ class cves_for_specific_component_query:
 
             for affect in self.osidb_session.affects.retrieve_list(
                 **cond,
-                limit=50,
+                limit=1000,
             ).results:
                 flaw = self.osidb_session.flaws.retrieve(affect.flaw)
                 if flaw:
